@@ -242,7 +242,7 @@ class array:
             raise Exception("All lists in the list should be the same length.\nThis also applies to lists in lists.")
     def __hash__(self : array) -> int:
         return hash("array%s,虞禱娑媟坂篩墮騨屹禱冗" %self.array_list)
-    def __to_array(data : array | list):
+    def __to_array(data : array or list):
         if type(data) == list:
             return array(data)
         return data
@@ -294,7 +294,7 @@ class array:
     #in
     def __contains__(self : array, other) -> bool:
         return other in self.array_list
-    def __getitem__(self : array, other : int | slice | tuple) -> int | float | complex | set | dimension | fract | array:
+    def __getitem__(self : array, other : int or slice or tuple) -> int or float or complex or set or dimension or fract or array:
         return array.__to_array(self.array_list[other])
     def __iter__(self : array) -> int:
         self.roop_time = -1
@@ -552,7 +552,7 @@ class __dimension: # coming Soon
                                                        .replace("8", "₈")\
                                                        .replace("9", "₉"))
         return "%s)" %ans
-    def __abs__(self) -> int | float:
+    def __abs__(self) -> int or float:
         ans = 0
         for number in self.imag_dict.values():
             ans += number ** 2
@@ -697,20 +697,17 @@ class fract:
     def __rge__(self, other):
         return self > other or self == other
 
-def gcd(*args) -> int | array:
-    n = args[0]
-    k = args[1]
+def gcd(*args):
+    if len(args) <= 1:
+        return args[0]
+    n, k, *others = args
     if k > n:
         n, k = k, n
     while k != 0:
         k, n = n % k, k
-    if 3 == len(args):
-        return gcd(n, args[2])
-    if 3 < len(args):
-        return gcd(n, eval("gcd%s" %str((args[2 : -1] + (args[-1],)))))
-    return n
+    return gcd(n, *others)
 
-def lcm(*args) -> int | array:
+def lcm(*args) -> int or array:
     args_max = max(args)
     n = 1
     while True:
@@ -722,14 +719,25 @@ def lcm(*args) -> int | array:
             return args_max * n
 
 @__memo
-def Sigma(_roop_time, _first_value, _formula) -> int | float | complex | set | dimension | fract | array:
+def sign(x):
+    return x / -x
+
+@__memo
+def theta(x):
+    if 0 < x:
+        return 1
+    else:
+        return 0
+
+@__memo
+def Sigma(_roop_time, _first_value, _formula) -> int or float or complex or set or dimension or fract or array:
     ans = 0
     for n in range(_first_value, _roop_time):
         ans += eval(_formula)
     return ans
 
 @__memo
-def Pi(_roop_time, _first_value, _formula) -> int | float | complex | set | dimension | fract | array:
+def Pi(_roop_time, _first_value, _formula) -> int or float or complex or set or dimension or fract or array:
     ans = 1
     for n in range(_first_value, _roop_time):
         ans *= eval(_formula)
@@ -750,7 +758,7 @@ def reduct_fract(_fr) -> fract:
     return _fr
 
 @__list
-def complex_test(_x) -> bool | array | list:
+def complex_test(_x) -> bool or array or list:
     """
     "complex_test(x)" returns whether x is a complex number.
     """
@@ -765,7 +773,7 @@ def complex_test(_x) -> bool | array | list:
 
 @__list
 @__memo
-def prime_test(_n) -> bool | array | list:
+def prime_test(_n) -> bool or array or list:
     """
     "prime_test(x)" returns whether x is a prime number.
     """
@@ -779,7 +787,7 @@ def prime_test(_n) -> bool | array | list:
 
 @__list
 @__memo
-def prime_fact(_n : int) -> array | list:
+def prime_fact(_n : int) -> array or list:
     """
     "prime_fact(x)" returns the result of factoring x into prime factors.
     """
@@ -815,7 +823,7 @@ def prime(_n : int):
 
 @__list
 @__memo
-def B(_n : int) -> fract | array | list:
+def B(_n : int) -> fract or array or list:
     ans = fract(0, 1)
     if _n == 0:
         return fract(1, 1)
@@ -856,9 +864,9 @@ def rad(_n : int) -> int:
     return ans
 
 @__list
-def div(_x : int | float | complex | dimension | fract | array | list,
-        _y : int | float | complex | dimension | fract | array | list)\
-          -> int | float | complex | dimension | fract | array | list:
+def div(_x : int or float or complex or dimension or fract or array or list,
+        _y : int or float or complex or dimension or fract or array or list)\
+          -> int or float or complex or dimension or fract or array or list:
     if _y == 0:
         if   0 < _x:
             return  inf()
@@ -872,29 +880,29 @@ def div(_x : int | float | complex | dimension | fract | array | list,
         return _x / _y
 
 @__list
-def imag_part(_x : int | float | complex | dimension | fract | array | list) -> int | float | array | list:
+def imag_part(_x : int or float or complex or dimension or fract or array or list) -> int or float or array or list:
     try:
         return _x.imag
     except:
         return 0
 
 @__list
-def real_part(_x : int | float | complex | dimension | fract | array | list) -> int | float | array | list:
+def real_part(_x : int or float or complex or dimension or fract or array or list) -> int or float or array or list:
     try:
         return _x.real
     except:
         return 0
 
 @__list
-def P(_n : int | float | complex | dimension | fract | array | list, 
-      _k : int | float | complex | dimension | fract | array | list)\
-        -> int | float | complex | dimension | fract | array | list:
+def P(_n : int or float or complex or dimension or fract or array or list, 
+      _k : int or float or complex or dimension or fract or array or list)\
+        -> int or float or complex or dimension or fract or array or list:
     return factorial(_n) / factorial(_k)
 
 @__list
-def C(_n : int | float | complex | dimension | fract | array | list, 
-      _k : int | float | complex | dimension | fract | array | list)\
-        -> int | float | complex | dimension | fract | array | list:
+def C(_n : int or float or complex or dimension or fract or array or list, 
+      _k : int or float or complex or dimension or fract or array or list)\
+        -> int or float or complex or dimension or fract or array or list:
     return P(_n, _k) / factorial(_k)
 
 def inf() -> float:
@@ -940,7 +948,7 @@ def tau() -> float:
 
 @__list
 @__memo
-def exp(_x : int | float | complex | dimension | fract | array | list) -> int | float | complex | dimension | fract | array | list:
+def exp(_x : int or float or complex or dimension or fract or array or list) -> int or float or complex or dimension or fract or array or list:
     """
     "exp(x)" returns the value of e power x.
     """
@@ -948,7 +956,7 @@ def exp(_x : int | float | complex | dimension | fract | array | list) -> int |
 
 @__list
 @__memo
-def zeta(x : int | float | complex | dimension | fract | array | list) -> int | float | complex | dimension | fract | array | list:
+def zeta(x : int or float or complex or dimension or fract or array or list) -> int or float or complex or dimension or fract or array or list:
     """
     "zeta(x)" returns the value of ζx.
     """
@@ -967,7 +975,7 @@ def zeta(x : int | float | complex | dimension | fract | array | list) -> int |
 
 @__list
 @__memo
-def ln(x : int | float | complex | dimension | fract | array | list) -> int | float | complex | dimension | fract | array | list:
+def ln(x : int or float or complex or dimension or fract or array or list) -> int or float or complex or dimension or fract or array or list:
     ans = x - 1
     ans_Pi = 1
     for n in range(1, 200):
@@ -976,36 +984,39 @@ def ln(x : int | float | complex | dimension | fract | array | list) -> int | fl
 
 @__list
 @__memo
-def log10(x : int | float | complex | dimension | fract | array | list) -> int | float | complex | dimension | fract | array | list:
+def log10(x : int or float or complex or dimension or fract or array or list) -> int or float or complex or dimension or fract or array or list:
     return log(10, x)
 
 @__list
 @__memo
-def log2(x : int | float | complex | dimension | fract | array | list) -> int | float | complex | dimension | fract | array | list:
+def log2(x : int or float or complex or dimension or fract or array or list) -> int or float or complex or dimension or fract or array or list:
     return log(2, x)
 
 @__list
 @__memo
-def log(x : int | float | complex | dimension | fract | array | list,
-        y : int | float | complex | dimension | fract | array | list)\
-         -> int | float | complex | dimension | fract | array | list:
+def log(x : int or float or complex or dimension or fract or array or list,
+        y : int or float or complex or dimension or fract or array or list)\
+         -> int or float or complex or dimension or fract or array or list:
     return div(ln(y) , ln(x))
 
 @__list
 @__memo
-def sqrt(x : int | float | complex | dimension | fract | array | list) -> int | float | complex | dimension | fract | array | list:
-    return x ** 0.5
+def sqrt(x : int or float or complex or dimension or fract or array or list) -> int or float or complex or dimension or fract or array or list:
+    return radical(x, 2)
 
 @__list
 @__memo
-def cube(x : int | float | complex | dimension | fract | array | list) -> int | float | complex | dimension | fract | array | list:
-    return x ** 0.3333333333333333333333333333333333333333
+def cube(x : int or float or complex or dimension or fract or array or list) -> int or float or complex or dimension or fract or array or list:
+    return radical(x, 3)
 
 @__list
 @__memo
-def radical(x : int | float | complex | dimension | fract | array | list, 
-            y : int | float | complex | dimension | fract | array | list)\
-             -> int | float | complex | dimension | fract | array | list:
+def radical(x : int or float or complex or dimension or fract or array or list, 
+            y : int or float or complex or dimension or fract or array or list)\
+             -> int or float or complex or dimension or fract or array or list:
+    if type(y) == int and type(x) == int:
+        if y < 0 and x % 2 == 1:
+            return -(abs(y) ** (1 / x))
     return y ** (1 / x)
 
 __Gamma_list : list = [
@@ -1022,21 +1033,20 @@ __Gamma_list : list = [
 @__del_complex
 @__pow
 @__memo
-def Gamma(x : int | float | complex | dimension | fract | array | list) -> int | float | complex | dimension | fract | array | list:
+def Gamma(x : int or float or complex or dimension or fract or array or list) -> int or float or complex or dimension or fract or array or list:
     if real_part(x) < 0.5:
         ans = pi() / (sin(pi() * x) * Gamma(1 - x))
     else:
-        x -= 1
         y = 0.99999999999980993
-        for (i, pval) in enumerate(__Gamma_list):
-            y += pval / (x + i + 1)
-        t = x + len(__Gamma_list) - 0.5
-        ans = sqrt(tau()) * t ** (x + 0.5) * exp(-t) * y
+        for (i, Gamma_v) in enumerate(__Gamma_list):
+            y += Gamma_v / (x + i)
+        t = x + len(__Gamma_list) - 1.5
+        ans = sqrt(tau()) * t ** (x - 0.5) * exp(-t) * y
     return ans
 
 @__list
 @__memo
-def factorial(_x : int | float | complex | dimension | fract | array | list) -> int | float | complex | dimension | fract | array | list:
+def factorial(_x : int or float or complex or dimension or fract or array or list) -> int or float or complex or dimension or fract or array or list:
     """
     "factorial(x)" returns the value of x!
     """
@@ -1054,7 +1064,7 @@ def factorial(_x : int | float | complex | dimension | fract | array | list) ->
 @__del_complex
 @__pow
 @__memo
-def sin(_θ : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def sin(_θ : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     """
     "sin(θ)" returns value of sine θ.
     >>> hmath.sin(6)
@@ -1072,7 +1082,7 @@ def sin(_θ : int | float | complex | dimension | fract | array | list, _n : int
 @__del_complex
 @__pow
 @__memo
-def cos(_θ : int | float | complex | dimension | fract | array | list, _n = 0) -> int | float | complex | dimension | fract | array | list:
+def cos(_θ : int or float or complex or dimension or fract or array or list, _n = 0) -> int or float or complex or dimension or fract or array or list:
     """
     "cos(θ)" returns value of cosine θ.
     >>> hmath.cos(6)
@@ -1090,7 +1100,7 @@ def cos(_θ : int | float | complex | dimension | fract | array | list, _n = 0)
 @__del_complex
 @__pow
 @__memo
-def tan(_θ : int | float | complex | dimension | fract | array | list, _n = 0) -> int | float | complex | dimension | fract | array | list:
+def tan(_θ : int or float or complex or dimension or fract or array or list, _n = 0) -> int or float or complex or dimension or fract or array or list:
     """
     "tan(θ)" returns value of tangent θ.
     >>> hmath.tan(6)
@@ -1107,7 +1117,7 @@ def tan(_θ : int | float | complex | dimension | fract | array | list, _n = 0)
 @__list
 @__pow
 @__memo
-def csc(_θ : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def csc(_θ : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     """
     "csc(θ)" returns value of cosec θ.
     >>> hmath.csc(6)
@@ -1124,139 +1134,139 @@ def csc(_θ : int | float | complex | dimension | fract | array | list, _n : int
 @__list
 @__pow
 @__memo
-def sec(_θ : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def sec(_θ : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     return div(1 , cos(_θ))
 
 @__list
 @__pow
 @__memo
-def cot(_θ : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def cot(_θ : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     return div(1 , tan(_θ))
 
 @__list
 @__del_complex
 @__pow
 @__memo
-def asin(_x : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def asin(_x : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     return -1j * ln(1j * _x + sqrt(1 - (_x ** 2)))
 
 @__list
 @__del_complex
 @__pow
 @__memo
-def acos(_x : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def acos(_x : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     return -1j * ln(_x - 1j * sqrt(1 - (_x ** 2)))
 
 @__list
 @__del_complex
 @__pow
 @__memo
-def atan(_x : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def atan(_x : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     return 1j * (ln(1 - _x * 1j) - ln(1 + _x * 1j)) / 2
 
 @__list
 @__del_complex
 @__pow
 @__memo
-def acsc(_x : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def acsc(_x : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     return asin(div(1 , _x))
 
 @__list
 @__pow
 @__memo
-def asec(_x : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def asec(_x : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     return acos(div(1 , _x))
 
 @__list
 @__pow
 @__memo
-def acot(_x : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def acot(_x : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     return atan(div(1 , _x))
 
 @__list
 @__pow
 @__memo
-def sinh(_x : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def sinh(_x : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     return (exp(_x) - exp(-_x)) / 2
 
 @__list
 @__pow
 @__memo
-def cosh(_x : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def cosh(_x : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     return (exp(_x) + exp(-_x)) / 2
 
 @__list
 @__pow
 @__memo
-def tanh(_x : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def tanh(_x : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     return sinh(_x) / cosh(_x)
 
 @__list
 @__pow
 @__memo
-def csch(_x : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def csch(_x : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     return 1 / sinh(_x)
 
 @__list
 @__pow
 @__memo
-def sech(_x : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def sech(_x : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     return 1 / cosh(_x)
 
 @__list
 @__pow
 @__memo
-def coth(_x : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def coth(_x : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     return 1 / tanh(_x)
 
 @__list
 @__pow
 @__memo
-def asinh(_x : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def asinh(_x : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     return ln(_x + sqrt((_x ** 2) + 1))
 
 @__list
 @__pow
 @__memo
-def acosh(_x : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def acosh(_x : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     return ln(_x + sqrt((_x + 1) * (_x - 1)))
 
 @__list
 @__pow
 @__memo
-def atanh(_x : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def atanh(_x : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     return ln((1 + _x) / (1 - _x)) / 2
 
 @__list
 @__pow
 @__memo
-def acsch(_x : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def acsch(_x : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     return asinh(1 / _x)
 
 @__list
 @__pow
 @__memo
-def asech(_x : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def asech(_x : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     return acosh(1 / _x)
 
 @__list
 @__pow
 @__memo
-def acoth(_x : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def acoth(_x : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     return atanh(1 / _x)
 
 @__list
-def radian(_θ) -> int | float | complex | dimension | fract | array | list:
+def radian(_θ) -> int or float or complex or dimension or fract or array or list:
     return _θ / 57.295779513082320876798154814105
 
 @__list
-def degrees(_θ) -> int | float | complex | dimension | fract | array | list:
+def degrees(_θ) -> int or float or complex or dimension or fract or array or list:
     return _θ * 57.295779513082320876798154814105
 
 @__list
 @__pow
 @__memo
-def diganma(_x : int | float | complex | dimension | fract | array | list, _n : int | str = 0) -> int | float | complex | dimension | fract | array | list:
+def diganma(_x : int or float or complex or dimension or fract or array or list, _n : int or str = 0) -> int or float or complex or dimension or fract or array or list:
     return Gamma(_x, "d") / Gamma(_x)
 
 π = pi
